/*
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.inteligr8.alfresco.acs;

import org.springframework.beans.factory.annotation.Value;

import com.inteligr8.rs.ClientConfiguration;

/**
 * This class provides a POJO &amp; Spring-based implementation of the
 * ClientConfiguration interface.  You can use it outside of the Spring
 * context, but you will need the spring-context and spring-beans libraries in
 * your non-Spring application.
 * 
 * @author brian@inteligr8.com
 */
public abstract class AcsClientConfiguration implements ClientConfiguration {

	@Value("${content.service.baseUrl:http://localhost:8080/alfresco}")
	private String baseUrl;

	@Value("${content.service.security.basicAuth.username:admin}")
	private String basicAuthUsername;

	@Value("${content.service.security.basicAuth.password:admin}")
	private String basicAuthPassword;

	@Value("${content.service.security.bearerToken:#{null}}")
	private String bearerToken;

	@Value("${content.service.security.oauth.tokenUrl:#{null}}")
	private String oAuthTokenUrl;

	@Value("${content.service.security.oauth.clientId:#{null}}")
	private String oAuthClientId;

	@Value("${content.service.security.oauth.clientSecret:#{null}}")
	private String oAuthClientSecret;

	@Value("${content.service.security.oauth.authCode:#{null}}")
	private String oAuthAuthCode;

	@Value("${content.service.security.oauth.authRedirectUri:#{null}}")
	private String oAuthAuthRedirectUri;

	@Value("${content.service.security.oauth.grantUsername:#{null}}")
	private String oAuthUsername;

	@Value("${content.service.security.oauth.grantPassword:#{null}}")
	private String oAuthPassword;

    @Value("${content.service.http.connectTimeout:#{null}}")
    private Integer connectTimeoutInMillis;

    @Value("${content.service.http.responseTimeout:#{null}}")
    private Integer responseTimeoutInMillis;

	public String getBaseUrl() {
		return this.baseUrl;
	}
	
	public void setBaseUrl(String baseUrl) {
		this.baseUrl = baseUrl;
	}
	
	public String getBasicAuthUsername() {
		return this.basicAuthUsername;
	}

	public void setBasicAuthUsername(String basicAuthUsername) {
		this.basicAuthUsername = basicAuthUsername;
	}
	
	public String getBasicAuthPassword() {
		return this.basicAuthPassword;
	}

	public void setBasicAuthPassword(String basicAuthPassword) {
		this.basicAuthPassword = basicAuthPassword;
	}
	
	public String getBearerToken() {
		return this.bearerToken;
	}

	public void setBearerToken(String bearerToken) {
		this.bearerToken = bearerToken;
	}
	
	public String getOAuthTokenUrl() {
		return this.oAuthTokenUrl;
	}

	public void setOAuthTokenUrl(String oAuthTokenUrl) {
		this.oAuthTokenUrl = oAuthTokenUrl;
	}
	
	public String getOAuthClientId() {
		return this.oAuthClientId;
	}

	public void setOAuthClientId(String oAuthClientId) {
		this.oAuthClientId = oAuthClientId;
	}
	
	public String getOAuthClientSecret() {
		return this.oAuthClientSecret;
	}

	public void setOAuthClientSecret(String oAuthClientSecret) {
		this.oAuthClientSecret = oAuthClientSecret;
	}
	
	public String getOAuthAuthCode() {
		return this.oAuthAuthCode;
	}

	public void setOAuthAuthCode(String oAuthAuthCode) {
		this.oAuthAuthCode = oAuthAuthCode;
	}
	
	public String getOAuthAuthRedirectUri() {
		return this.oAuthAuthRedirectUri;
	}

	public void setOAuthAuthRedirectUri(String oAuthAuthRedirectUri) {
		this.oAuthAuthRedirectUri = oAuthAuthRedirectUri;
	}
	
	public String getOAuthUsername() {
		return this.oAuthUsername;
	}

	public void setOAuthUsername(String oAuthUsername) {
		this.oAuthUsername = oAuthUsername;
	}
	
	public String getOAuthPassword() {
		return this.oAuthPassword;
	}

	public void setOAuthPassword(String oAuthPassword) {
		this.oAuthPassword = oAuthPassword;
	}
	
	@Override
	public Integer getConnectTimeoutInMillis() {
	    return this.connectTimeoutInMillis;
	}
	
	public void setConnectTimeoutInMillis(Integer connectTimeoutInMillis) {
        this.connectTimeoutInMillis = connectTimeoutInMillis;
    }
	
	@Override
	public Integer getResponseTimeoutInMillis() {
	    return this.responseTimeoutInMillis;
	}
	
	public void setResponseTimeoutInMillis(Integer responseTimeoutInMillis) {
        this.responseTimeoutInMillis = responseTimeoutInMillis;
    }

}
